import click
import http.client
import json
import textwrap

from dodonacli.source import set_data
from dodonacli.source import pretty_console, get_data


@click.command(help="Select based on id or name. Depends on current selection. If nothing is selected, "
                    "it will try to select a course, then an exercise-series, then an exercise. Will not work "
                    "with invalid id's or names.")
@click.option("--hidden", "-hidden",
              help="Access a hidden series. Only available when trying to select a series.\n\n\t"
                   "Usage: dodona select --hidden <TOKEN> <SERIES_ID>")
@click.argument('thing')
def select(thing, hidden):
    # Read configs in
    config = get_data.get_configs()

    # Start up the connection to Dodona
    connection = http.client.HTTPSConnection("dodona.be")
    headers = {
        "Content-type": "application/json",
        "Accept": "application/json",
        "Authorization": config['TOKEN']
    }

    if config['course_id'] is None:
        config = select_course(connection, headers, thing, config)

    elif config['serie_id'] is None:
        if hidden:
            config = select_hidden_series(connection, headers, thing, hidden, config)
        else:
            config = select_series(connection, headers, thing, config)

    elif config['exercise_id'] is None:
        config = select_exercise(connection, headers, thing, config)

    else:
        # You can't select more when everything is already selected
        print('There is already an exercise selected, '
              'please remove selection with --up or -u to select a new exercise first.')

    # Save selections in config file
    set_data.dump_config(config)


def select_course(connection: http.client.HTTPSConnection, headers: dict,
                  thing: str, config: dict):
    data_courses = get_data.courses_data(connection, headers)

    courses = {str(course['id']): course['name'] for course in data_courses}

    # If select is an ID, search if it matches id's, else search if it matches a name, then store the ID
    if thing.isnumeric() and thing in courses:
        config['course_id'] = thing
        config['course_name'] = courses[thing]
        pretty_console.console.print("\nCourse [bold]" + courses[thing] + "[/] selected.\n")
    else:
        for course in courses.items():
            if thing.lower() in course[1].lower():
                config['course_id'] = course[0]
                config['course_name'] = course[1]
                pretty_console.console.print("\nCourse [bold]\"" + courses[course[0]] + "\"[/] selected.\n")
                break
    if config['course_id'] is None:
        print("\nNot a valid course id or -name!\n")

    return config


def select_series(connection: http.client.HTTPSConnection, headers: dict,
                  thing: str, config: dict):
    data_series = get_data.series_data(connection, headers, config['course_id'])

    series = {str(serie['id']): serie['name'] for serie in data_series}

    if thing.isnumeric() and thing in series:
        config['serie_id'] = thing
        config['serie_name'] = series[thing]
        pretty_console.console.print("\nSeries [bold]\"" + series[thing] + "\"[/] selected.\n")
    else:
        for serie in series.items():
            if thing.lower() in serie[1].lower():
                config['serie_id'] = serie[0]
                config['serie_name'] = serie[1]
                pretty_console.console.print("\nSerie [bold]\"" + series[serie[0]] + "\"[/] selected.\n")
                break
    if config['serie_id'] is None:
        print("\nNot a valid series id or -name!\n")

    return config


def select_hidden_series(connection: http.client.HTTPSConnection, headers: dict,
                         series_id: str, series_token: str, config: dict):
    # https://dodona.be/nl/series/30841/?token=Gd2EF

    if not series_id.isnumeric():
        print("Well this won't work without a valid ID (only numeric characters). Please try again")
        return config

    link = f"/series/{series_id}?token={series_token}"
    connection = get_data.handle_connection_request(connection, "GET", link, headers)

    res = connection.getresponse()

    if res.status != 200:
        print("Something went wrong trying to select the hidden series.\n"
              "Check if you got the right series-id (seen in /series/<serie_id> in the link you got).\n"
              "\tResponse code: " + str(res.status) +
              "\n\tReason: " + str(res.reason))
        return config

    json_data = json.loads(res.read())
    config['serie_id'] = series_id
    config['serie_name'] = json_data['name']
    config['serie_token'] = series_token

    pretty_console.console.print(f"\nSerie [bold]\"{json_data['name']}\"[/] selected.\n")

    return config


def select_exercise(connection: http.client.HTTPSConnection, headers: dict,
                    thing: str, config: dict) -> dict:
    if config['serie_token'] is None:
        serie_token = ""
    else:
        serie_token = "?token=" + config['serie_token']

    data_exercises = get_data.exercises_data(connection, headers, config['serie_id'], serie_token)

    exercises = {str(exercise['id']): (exercise['name'], i) for i, exercise in enumerate(data_exercises)}

    if thing.isnumeric() and thing in exercises:
        config['exercise_id'] = thing
        config['exercise_name'] = exercises[thing]
        pretty_console.console.print("\nExercise [bold]\"" + exercises[thing] + "\"[/] selected.\n")
    else:
        for exercise in exercises.items():
            exercise_id, (exercise_name, number) = exercise
            if thing.lower() in exercise_name.lower():
                config['exercise_id'] = exercise_id
                config['exercise_name'] = exercise_name
                pretty_console.console.print(
                    "\nExercise [bold]\"" + exercises[exercise_id][0] + "\"[/] selected.\n")
                boilerplate = data_exercises[number].get("boilerplate")
                if boilerplate is not None and boilerplate.strip() != "":
                    print("\nBoilerplate code (can be found in boilerplate-file):\n")
                    print(textwrap.indent(boilerplate, '\t'))

                    with open("boilerplate", "w") as boilerplate_file:
                        boilerplate_file.write(boilerplate)
                break

    if config['exercise_id'] is None:
        print("Not a valid exercise id or -name!")

    return config



import http.client
import json
import os
import socket

from . import set_data, interactive_tutorial


def handle_connection_request(connection: http.client.HTTPSConnection, connection_type: str,
                              link: str, headers: dict) -> http.client.HTTPSConnection:
    try:
        connection.request(connection_type, link, headers=headers)

    except socket.gaierror:
        print("Something went wrong trying to connect to Dodona. This is probably an internet connection problem.")
        exit(2)

    return connection


def handle_connection_response(connection: http.client.HTTPSConnection) -> bytes:
    """
    Handle response from Dodona connection
    Terminates program if there was a problem with the connection
    :param connection: HTTPSConnection object that has had a request
    :return: data
    """
    res = connection.getresponse()
    status = res.status
    if status != 200:
        print("Error connecting to Dodona: " + str(status))
        print("Reason: " + res.reason)
        exit(-1)

    data = res.read()
    connection.close()

    return data


def courses_data(connection: http.client.HTTPSConnection, headers: dict):
    """
    Get registred courses of user
    :param connection: HTTPSConnection object to the main Dodona page
    :param headers: Dict with extra info, mainly autorization needed
    :return: json object with info about available courses
    """
    connection = handle_connection_request(connection, "GET", "/courses?tab=my", headers)
    data = handle_connection_response(connection)

    return json.loads(data)


def series_data(connection: http.client.HTTPSConnection, headers: dict, course_id: str):
    """
    Get all exercise-series of course
    :param connection: HTTPSConnection object to the main Dodona page
    :param headers: Dict with extra info, mainly autorization needed
    :param course_id: int id of the course to find series from
    :return: json object with info about available series
    """
    connection = handle_connection_request(connection, "GET", "/courses/" + course_id + "/series", headers=headers)
    data = handle_connection_response(connection)

    return json.loads(data)


def exercises_data(connection: http.client.HTTPSConnection, headers: dict, series_id: str, serie_token: str = ""):
    """
    Get all exercises of exercise-serie
    :param connection: HTTPSConnection object to the main Dodona page
    :param headers: Dict with extra info, mainly autorization needed
    :param series_id: int id of exercise-series
    :param serie_token: Token of a hidden series
    :return: json object with info about available exercises
    """
    connection = handle_connection_request(
        connection,
        "GET",
        "/series/" + series_id + "/activities" + serie_token,
        headers=headers
    )
    data = handle_connection_response(connection)

    return json.loads(data)


def exercise_data(connection: http.client.HTTPSConnection, headers: dict, course_id: str, exercise_id: str):
    """
    Get exercise-info for selected exercise
    :param connection: HTTPSConnection object to the main Dodona page
    :param headers: Dict with extra info, mainly autorization needed
    :param course_id: int id of course
    :param exercise_id: int id of exercise
    :return: json object with info about exercise
    """
    connection = handle_connection_request(
        connection, "GET",
        "/courses/" + course_id + "/activities/" + exercise_id,
        headers=headers
    )
    data = handle_connection_response(connection)

    return json.loads(data)


def exercise_submissions(config: dict, connection: http.client.HTTPSConnection, headers: dict):
    course_id = config['course_id']
    series_id = config['serie_id']
    exercise_id = config['exercise_id']

    connection = handle_connection_request(
        connection,
        "GET",
        f"/courses/{course_id}/series/{series_id}/activities/{exercise_id}/submissions",
        headers=headers
    )
    data = handle_connection_response(connection)

    return json.loads(data)


def all_submissions(connection: http.client.HTTPSConnection, headers: dict):
    connection = handle_connection_request(
        connection,
        "GET",
        "/submissions",
        headers=headers
    )
    data = handle_connection_response(connection)

    return json.loads(data)


def submission_info(sub_id: int, connection: http.client.HTTPSConnection, headers: dict, config):
    connection = handle_connection_request(
        connection,
        "GET",
        f"/submissions/{sub_id}",
        headers=headers
    )
    data = handle_connection_response(connection)
    json_data = json.loads(data)

    exercise_id = json_data['exercise'].split('/')[-1].replace('.json', '')

    exercise = exercise_data(connection, headers, config['course_id'], exercise_id)

    json_data['exercise_name'] = exercise['name']

    return json_data


def get_configs():
    """
    Get config data from config.json
    :return: json object with config data
    """
    # Get the path of the config-file.
    # This is a bit more complicated because this file exists in the same directory as
    # the python files, but the command may be executed from anywhere with the appropriate alias set.
    # Thus, first the path to the directory of the python files is retrieved; then the config-file-name is appended
    script_directory = os.path.dirname(os.path.abspath(__file__))
    config_file_path = os.path.join(script_directory, '../../config.json')

    # First try to open, if unable to open, create a new config-file and ask user for a token
    try:
        with open(config_file_path, "r") as file:
            config = json.load(file)

            config = validate_config(config)

    except FileNotFoundError:
        # Create config dictionary
        config = {e: None
                  for e in ["course_id", "course_name", "serie_id", "serie_name", "exercise_id", "exercise_name"]}

        print("\nThis may be your first time using DodonaCLI, do you wish to follow a short tutorial?")
        answer = input("(yes/no): ")

        if answer.lower().startswith("yes"):
            config = interactive_tutorial.start_tutorial(config)
        else:
            TOKEN = input('API-Token not found! Enter your code here: ')
            config["TOKEN"] = TOKEN

        # Save configs
        set_data.dump_config(config)

        exit(0)

    return config


def validate_config(config: dict):
    """
    Checks whether the config file contains all the necessary keys.
    This is needed when an update introduces new keys.
    :param config: Dictionary with the content of config.json
    :return: Updated config dictionary
    """
    keys_to_check = (
        "course_id", "course_name",
        "serie_id", "serie_name",
        "exercise_id", "exercise_name",
        "serie_token"
    )
    for key in keys_to_check:
        if key not in config:
            config[key] = None

    if "TOKEN" not in config:
        print("API token not found.")
        config = get_api_token(config)

    return config


def get_api_token(config: dict):
    """
    Asks the user for an API token and saves it
    :param config: Dictionary with the content of config.json
    :return: Updated config dictionary
    """
    config['TOKEN'] = input("Paste your API-token here: ")
    set_data.dump_config(config)

    return config



"""
This file will contain everything needed to provide a tutorial to first-time users.
It uses "The Coder's Apprentice" featured course on Dodona.
"""
import http.client
import json
import os

import dodonacli.source.get_data
from . import pretty_print, pretty_console, set_data


def start_tutorial(config: dict):
    """
    Runs the tutorial and asks for API token if it wasn't present yet.
    :param config: dict
    :return: config: dict
    """
    os.system('cls' if os.name == 'nt' else 'clear')
    print("\nWelcome to the Dodona CLI, "
          "this tutorial will show you everything you need to interact with Dodona from your terminal.")

    config['serie_id'], config['serie_name'], config['exercise_id'], config['exercise_name'] = None, None, None, None

    if "TOKEN" not in config:
        pretty_console.console.print(
            "\n\nBefore we begin, we'll need an API-token to authorize your connection with Dodona. "
            "You can find it on your profile page on https://dodona.be")

        config = dodonacli.source.get_data.get_api_token(config)

    connection = http.client.HTTPSConnection("dodona.be")
    headers = {
        "Content-type": "application/json",
        "Accept": "application/json",
        "Authorization": config['TOKEN']
    }

    config = tutorial_select_course(config, connection, headers)
    config = tutorial_select_series(config, connection, headers)
    config = tutorial_select_exercise(config, connection, headers)
    tutorial_view_exercise(config, connection, headers)
    tutorial_post_exercise(config, connection, headers)

    config = tutorial_conclude(config)

    return config


def tutorial_handle_connection(config: dict, connection: http.client.HTTPSConnection):
    res = connection.getresponse()
    status = res.status

    if status != 200:
        if status == 401:
            print("Authorization didn't work, please re-enter your API-token and make sure it's correct.")
            config = dodonacli.source.get_data.get_api_token(config)
            set_data.dump_config(config)

        else:
            pretty_console.console.print("Error connecting to Dodona: " + str(status))
            pretty_console.console.print("Reason: " + res.reason)

        pretty_console.console.print("Tutorial will terminate due to error, you can start again with `dodona tutorial`")
        exit(-1)

    data = res.read()
    connection.close()

    return json.loads(data)


def tutorial_select_course(config: dict, connection: http.client.HTTPSConnection, headers: dict):
    pretty_console.console.print("\n\n\nUse the command `dodona display` to show the available courses.")

    command = input("$ ")

    while command.rstrip() != "dodona display":
        print("That was not the right command, please try again")
        command = input("$ ")

    connection.request("GET", "/courses?tab=featured", headers=headers)
    json_data = tutorial_handle_connection(config, connection)

    pretty_print.print_courses_data(json_data, "Featured courses")

    pretty_console.console.print("Select now \"The Coder's Apprenctice\" with `dodona select` + "
                                 "the courses id, or (distinct part of) the courses name")
    command = input("$ ")

    while not command.rstrip().startswith("dodona select"):
        print("That was not the right command, please try again")
        command = input("$ ")

    if (len(command.split()) < 3 or
            command.split()[2] != "296" and command.split()[2].lower() not in "The Coder's Apprentice".lower()):
        pretty_console.console.print(
            "Watch out, you used a wrong id or name to select \"The Coder's Apprentice\"!\n"
            "The tutorial will continue as if you selected it right, but pay attention next time."
        )

    config['course_id'] = 296
    config['course_name'] = "The Coder's Apprentice"

    pretty_console.console.print("\nThe course is now selected, use `dodona status` to view your selection:")
    command = input("$ ")

    while not command.rstrip() == "dodona status":
        print("That was not the right command, please try again")
        command = input("$ ")

    pretty_print.print_status(config)
    print("Fantastic, let's move on to selecting an exercise series.")

    return config


def tutorial_select_series(config: dict, connection: http.client.HTTPSConnection, headers: dict):
    pretty_console.console.print("\n\n\nUse the command `dodona display` to show the available exercise-series. ")

    command = input("$ ")

    while command.rstrip() != "dodona display":
        print("That was not the right command, please try again")
        command = input("$ ")

    connection.request("GET", "/courses/" + str(config['course_id']) + '/series', headers=headers)
    json_data = tutorial_handle_connection(config, connection)

    # To prevent the screen being blasted with a lot of text, only print out the first 6 exercise series
    pretty_print.print_series_data(json_data[:6])

    pretty_console.console.print("Select now \"2. Using Python\" with `dodona select` + "
                                 "the series' id, or (distinct part of) the series' name")
    command = input("$ ")

    while not command.rstrip().startswith("dodona select"):
        print("That was not the right command, please try again")
        command = input("$ ")

    if (len(command.split()) < 3
            or command.split()[2] != "2592" and command.split()[2].lower() not in "2. Using Python".lower()):
        pretty_console.console.print(
            "Watch out, you used a wrong id or name to select \"2. Using Python\"!\n"
            "The tutorial will continue as if you selected it right, but pay attention next time."
        )

    config['serie_id'] = 2592
    config['serie_name'] = "2. Using Python"

    pretty_console.console.print("\nThe exercise-series is now selected, use `dodona status` to view your selection:")
    command = input("$ ")

    while not command.rstrip() == "dodona status":
        print("That was not the right command, please try again")
        command = input("$ ")

    pretty_print.print_status(config)
    print("Fantastic, let's move on to selecting an exercise.")

    return config


def tutorial_select_exercise(config: dict, connection: http.client.HTTPSConnection, headers: dict):
    pretty_console.console.print("\n\n\nUse the command `dodona display` to show the available exercises. ")

    command = input("$ ")

    while command.rstrip() != "dodona display":
        print("That was not the right command, please try again")
        command = input("$ ")

    connection.request("GET", "/series/" + str(config['serie_id']) + '/activities', headers=headers)
    json_data = tutorial_handle_connection(config, connection)

    pretty_print.print_exercise_data(json_data)

    pretty_console.console.print("Select now \"Hello, World!\" with `dodona select` + "
                                 "the series' id, or (distinct part of) the series' name")
    command = input("$ ")

    while not command.rstrip().startswith("dodona select"):
        print("That was not the right command, please try again")
        command = input("$ ")

    if (len(command.split()) < 3 or
            command.split()[2] != "1399231809" and command.split()[2].lower() not in "Hello, World!".lower()):
        pretty_console.console.print(
            "Watch out, you used a wrong id or name to select \"2. Using Python\"!\n"
            "The tutorial will continue as if you selected it right, but pay attention next time."
        )

    config['exercise_id'] = 1399231809
    config['exercise_name'] = "Hello, World!"

    # This exercise has boilerplate code
    with open('boilerplate', 'w') as boilerplate:
        boilerplate.write(json_data[5]['boilerplate'])
    print(
        "\nThis exercise has some boilerplate code attached to it, you can view it in the boilerplate file, or here:\n"
        " |\t" + json_data[5]['boilerplate']
    )

    pretty_console.console.print("\nThe exercise is now selected, use `dodona status` to view your selection:")
    command = input("$ ")

    while not command.rstrip() == "dodona status":
        print("That was not the right command, please try again")
        command = input("$ ")

    pretty_print.print_status(config)
    print("Fantastic, let's move on to viewing an exercise description.")

    return config


def tutorial_view_exercise(config: dict, connection: http.client.HTTPSConnection, headers: dict):
    pretty_console.console.print("\n\n\nUse the command `dodona display` to show the description of the exercise. ")

    command = input("$ ")

    while command.rstrip() != "dodona display":
        print("That was not the right command, please try again")
        command = input("$ ")

    connection.request("GET", "/courses/" + str(config['course_id'])
                       + "/series/" + str(config['serie_id'])
                       + '/activities/' + str(config['exercise_id']),
                       headers=headers)
    json_data = tutorial_handle_connection(config, connection)

    pretty_print.print_exercise(json_data, config['TOKEN'])


def tutorial_post_exercise(config: dict, connection: http.client.HTTPSConnection, headers: dict):
    pretty_console.console.print(
        "\n\n\nNow you can post the solution. You don't need to write any code for it, as it is already writtin in "
        "the 'boilerplate'-file. You can post it by writing `dodona post <SOLUTION_FILE_NAME>`."
        "Replace <SOLUTION_FILE_NAME> with the correct file-name, in this case 'boilerplate'.")

    command = input("$ ")

    while command.rstrip() != "dodona post boilerplate":
        print("That was not the right command, please try again")
        command = input("$ ")

    with open('boilerplate', 'r') as solution_file:
        set_data.post_solution(solution_file.read(), connection, headers, config)


def tutorial_conclude(config: dict):
    pretty_console.console.print(
        "\nAlmost done, now deselect everything with `dodona uptop` and you're ready to use DodonaCLI."
        "\nRemember you can always use `dodona --help` to view all available commands and flags.")

    command = input("$ ")

    while command.rstrip() != "dodona uptop":
        print("That was not the right command, please try again")
        command = input("$ ")

    for e in ('exercise_id', 'exercise_name', 'serie_id', 'serie_name', 'course_id', 'course_name'):
        config[e] = None

    return config



import json
import os
import random
import rich.status
import time

from datetime import datetime

from . import pretty_print, pretty_console


def dump_config(config):
    script_directory = os.path.dirname(os.path.abspath(__file__))
    config_file_path = os.path.join(script_directory, '../../config.json')

    with open(config_file_path, 'w') as config_file:
        json.dump(config, config_file)


def post_solution(content, connection, headers, config):
    """
    Post the solution in content to Dodona and print the result
    :param content: str with the solution to post to Dodona
    :param connection: HTTPSConnection object that connects to www.dodona.be
    :param headers: dict with extra info for connection, mainly authorization needed
    :param config: dict with configs from config-file
    """
    # Make dict with info needed to post the solution and dump it in a json object
    payload = {
        "submission": {
            "code": content,
            "course_id": config['course_id'],
            "exercise_id": config['exercise_id']
        }
    }
    json_payload = json.dumps(payload)

    # Connect to Dodona and post the solution
    connection.request("POST", "/submissions.json", json_payload, headers=headers)
    res = connection.getresponse()
    status = res.status
    if status == 422:
        pretty_console.console.print("\n[i]Patience, young padawan.\n"
                                     "A cooldown, Dodona servers have, to prevent DDOS attacks, hmm, yes.[/]\n")
        return

    elif status != 200:
        print("\nError connection to Dodona: " + str(res.status))
        print("Reason: " + res.reason + '\n')
        return

    # Read out the result
    data = res.read()
    json_data = json.loads(data)

    # The Dodona servers take some time to test the solution, so we ping them every 0.3s for an answer.
    json_data['status'] = "running"

    print()

    waiting = rich.status.Status("Posting your solution, please wait while the servers evaluate your code.",
                                 spinner=select_spinner())
    waiting.start()
    wait_interval = 0

    while json_data['status'] in ("running", "queued"):
        # Aks the servers for the result with an increasing interval, from 1s to 5s, as the website does
        time.sleep(wait_interval)
        if wait_interval < 5:
            wait_interval += 1

        connection.request("GET", "/submissions/" + str(json_data['id']) + ".json", headers=headers)
        res = connection.getresponse()
        if res.status != 200:
            print("Error connection to Dodona: " + str(res.status))
            print("Reason: " + res.reason)
            return

        data = res.read()
        json_data = json.loads(data)

    waiting.stop()
    connection.close()

    # Print out the results
    pretty_print.print_result(json.loads(json_data['result']))
    print()


def select_spinner():
    selection_spinners = ['arrow', 'balloon', 'balloon2', 'bouncingBar', 'boxBounce', 'boxBounce2', 'circle',
                          'circleHalves', 'circleQuarters', 'clock', 'dots2', 'dots3', 'dots4', 'dots5', 'dots6',
                          'dots7', 'dots8', 'dots8Bit', 'dots9', 'dots10', 'dots11', 'dots12', 'dqpb', 'flip',
                          'hamburger', 'layer', 'line', 'line2', 'moon', 'pipe', 'point', 'runner', 'simpleDots',
                          'simpleDotsScrolling', 'squareCorners']

    christmas_spinner = 'christmas'

    # Get the current date
    current_date = datetime.now().date()

    # Define the Christmas season range
    christmas_start = datetime(current_date.year, 12, 11).date()
    christmas_end = datetime(current_date.year, 1, 8).date()

    # Check if the current date is within the Christmas season range
    is_christmas_season = not christmas_start > current_date > christmas_end

    if is_christmas_season:
        return christmas_spinner

    return random.choice(selection_spinners)


def save_submission_code(exer_name: str, sub_id: int, sub_code: str):
    file_name = f"{exer_name}_{sub_id}"

    with open(file_name, "w") as code_file:
        code_file.write(sub_code)

    print(f"\nCode from your submission for {exer_name} is now saved in:\n"
          f"\t{exer_name}_{sub_id}\n")



import click
import http.client

from dodonacli.source import set_data
from dodonacli.source import get_data


@click.command(help="Post a solution-file to Dodona. "
                    "The file has to be in your current working directory, and this only works "
                    "if there is a selected exercise.")
@click.argument('file', type=click.Path(exists=True, file_okay=True, dir_okay=False, resolve_path=True))
def post(file):
    # Read configs in
    config = get_data.get_configs()

    # Start up the connection to Dodona
    connection = http.client.HTTPSConnection("dodona.be")
    headers = {
        "Content-type": "application/json",
        "Accept": "application/json",
        "Authorization": config['TOKEN']
    }

    # Post exercise to Dodona, does not work if there is no exercise selected
    if not config['exercise_id']:
        print("\nNo exercise selected!\n")
    else:
        with open(file, 'r') as infile:
            content = infile.read()
        set_data.post_solution(content, connection, headers, config)

